@@ -24,13 +24,16 @@ import java.util.SortedMap;
 import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 
+import org.drools.scenariosimulation.api.model.AbstractScesimModel;
 import org.drools.scenariosimulation.api.model.ExpressionElement;
 import org.drools.scenariosimulation.api.model.FactIdentifier;
 import org.drools.scenariosimulation.api.model.FactMapping;
 import org.drools.scenariosimulation.api.model.FactMappingType;
+import org.drools.scenariosimulation.api.model.FactMappingValueType;
 import org.drools.scenariosimulation.api.model.ScenarioSimulationModel;
 import org.drools.scenariosimulation.api.utils.ScenarioSimulationSharedUtils;
 import org.drools.workbench.screens.scenariosimulation.client.commands.ScenarioSimulationContext;
+import org.drools.workbench.screens.scenariosimulation.client.enums.GridWidget;
 import org.drools.workbench.screens.scenariosimulation.client.metadata.ScenarioHeaderMetaData;
 import org.drools.workbench.screens.scenariosimulation.client.resources.i18n.ScenarioSimulationEditorConstants;
 import org.drools.workbench.screens.scenariosimulation.client.utils.ConstantHolder;
@@ -46,10 +49,16 @@ import static org.drools.workbench.screens.scenariosimulation.client.utils.Scena
 /**
  * <b>Abstract</b> <code>Command</code> class which assures that a <code>ScenarioColumn</code> is selected.
  */
-public abstract class AbstractSelectedColumnCommand extends AbstractScenarioSimulationCommand {
+public abstract class AbstractSelectedColumnCommand extends AbstractScenarioGridCommand {
 
-    public AbstractSelectedColumnCommand() {
-        super(true);
+    protected FactMappingValueType factMappingValueType = FactMappingValueType.NOT_EXPRESSION;
+
+    protected AbstractSelectedColumnCommand(GridWidget gridWidget, FactMappingValueType factMappingValueType) {
+        super(gridWidget);
+        this.factMappingValueType = factMappingValueType;
+    }
+
+    protected AbstractSelectedColumnCommand() {
     }
 
     protected abstract void executeIfSelectedColumn(ScenarioSimulationContext context, ScenarioGridColumn selectedColumn);
@@ -72,7 +81,7 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioSimu
         String columnGroup = selectedInformationHeaderMetaData.getColumnGroup();
         String originalInstanceTitle = selectedInformationHeaderMetaData.getTitle();
         final FactMappingType factMappingType = FactMappingType.valueOf(columnGroup.toUpperCase());
-        final Map.Entry<String, String> validPlaceholders = context.getModel().getValidPlaceholders();
+        final Map.Entry<String, String> validPlaceholders = context.getAbstractScesimGridModelByGridWidget(gridWidget).getValidPlaceholders();
         String instanceTitle = cloneInstance ? originalInstanceTitle : validPlaceholders.getKey();
         String propertyTitle = validPlaceholders.getValue();
         String placeHolder = ScenarioSimulationEditorConstants.INSTANCE.defineValidType();
@@ -81,15 +90,15 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioSimu
                                                                                       String.valueOf(new Date().getTime()),
                                                                                       columnGroup,
                                                                                       factMappingType,
-                                                                                      context.getScenarioHeaderTextBoxSingletonDOMElementFactory(),
-                                                                                      context.getScenarioCellTextAreaSingletonDOMElementFactory(),
+                                                                                      context.getScenarioHeaderTextBoxSingletonDOMElementFactory(gridWidget),
+                                                                                      context.getScenarioCellTextAreaSingletonDOMElementFactory(gridWidget),
                                                                                       placeHolder);
         if (cloneInstance) {
             scenarioGridColumnLocal.setFactIdentifier(selectedColumn.getFactIdentifier());
         }
         scenarioGridColumnLocal.setInstanceAssigned(cloneInstance);
         scenarioGridColumnLocal.setPropertyAssigned(false);
-        context.getModel().insertColumn(columnPosition, scenarioGridColumnLocal);
+        context.getAbstractScesimGridModelByGridWidget(gridWidget).insertColumn(columnPosition, scenarioGridColumnLocal);
         return scenarioGridColumnLocal;
     }
 
@@ -99,12 +108,19 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioSimu
      * @param selectedColumn The selected <code>ScenarioGridColumn</code> where the command was launched
      */
     protected void setInstanceHeader(ScenarioSimulationContext context, ScenarioGridColumn selectedColumn, String alias, String fullClassName) {
-        int columnIndex = context.getModel().getColumns().indexOf(selectedColumn);
+        int columnIndex = context.getAbstractScesimGridModelByGridWidget(gridWidget).getColumns().indexOf(selectedColumn);
         final FactIdentifier factIdentifier = setEditableHeadersAndGetFactIdentifier(context, selectedColumn, alias, fullClassName);
         setInstanceHeaderMetaData(selectedColumn, alias, factIdentifier);
         final ScenarioHeaderMetaData propertyHeaderMetaData = selectedColumn.getPropertyHeaderMetaData();
-        setPropertyMetaData(propertyHeaderMetaData, getPropertyPlaceHolder(columnIndex), false, selectedColumn, ScenarioSimulationEditorConstants.INSTANCE.defineValidType());
-        context.getModel().updateColumnInstance(columnIndex, selectedColumn);
+        setPropertyMetaData(propertyHeaderMetaData,
+                            getPropertyPlaceHolder(columnIndex),
+                            false,
+                            selectedColumn,
+                            ScenarioSimulationUtils.getPlaceHolder(selectedColumn.isInstanceAssigned(),
+                                                                   selectedColumn.isPropertyAssigned(),
+                                                                   factMappingValueType,
+                                                                   fullClassName));
+        context.getAbstractScesimGridModelByGridWidget(gridWidget).updateColumnInstance(columnIndex, selectedColumn);
         if (context.getScenarioSimulationEditorPresenter() != null) {
             context.getScenarioSimulationEditorPresenter().reloadTestTools(false);
         }
@@ -116,7 +132,7 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioSimu
      * @return
      */
     protected Optional<ScenarioGridColumn> getSelectedColumn(ScenarioSimulationContext context) {
-        return Optional.ofNullable((ScenarioGridColumn) context.getModel().getSelectedColumn());
+        return Optional.ofNullable((ScenarioGridColumn) context.getAbstractScesimGridModelByGridWidget(gridWidget).getSelectedColumn());
     }
 
     /**
@@ -141,8 +157,8 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioSimu
      * @return
      */
     protected FactIdentifier setEditableHeadersAndGetFactIdentifier(ScenarioSimulationContext context, ScenarioGridColumn selectedColumn, String aliasName, String canonicalClassName) {
-        final ScenarioSimulationModel.Type simulationModelType = context.getModel().getSimulation().get().getSimulationDescriptor().getType();
-        selectedColumn.setEditableHeaders(!simulationModelType.equals(ScenarioSimulationModel.Type.DMN));
+        final ScenarioSimulationModel.Type simulationModelType = context.getSettings().getType();
+        selectedColumn.setEditableHeaders(!(simulationModelType.equals(ScenarioSimulationModel.Type.DMN) || GridWidget.BACKGROUND.equals(gridWidget)));
         String nameToUseForCreation = simulationModelType.equals(ScenarioSimulationModel.Type.DMN) ? aliasName : selectedColumn.getInformationHeaderMetaData().getColumnId();
         return getFactIdentifierByColumnTitle(aliasName, context).orElseGet(() -> FactIdentifier.create(nameToUseForCreation, canonicalClassName));
     }
@@ -202,32 +218,41 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioSimu
         if (propertyTitle == null) {
             throw new IllegalArgumentException("Property title can not be null");
         }
-        int columnIndex = context.getModel().getColumns().indexOf(selectedColumn);
+        int columnIndex = context.getAbstractScesimGridModelByGridWidget(gridWidget).getColumns().indexOf(selectedColumn);
         String instanceAliasName = propertyNameElements.get(0);
         if (selectedColumn.isInstanceAssigned() && !instanceAliasName.equals(selectedColumn.getInformationHeaderMetaData().getTitle())) {
             throw new IllegalArgumentException("It's not possible to assign this property");
         }
         String className = factIdentifier.getClassName();
-        final GridData.Range instanceLimits = context.getModel().getInstanceLimits(columnIndex);
+        final GridData.Range instanceLimits = context.getAbstractScesimGridModelByGridWidget(gridWidget).getInstanceLimits(columnIndex);
         IntStream.range(instanceLimits.getMinRowIndex(), instanceLimits.getMaxRowIndex() + 1)
                 .forEach(index -> {
-                    final ScenarioGridColumn scenarioGridColumn = (ScenarioGridColumn) context.getModel().getColumns().get(index);
+                    final ScenarioGridColumn scenarioGridColumn = (ScenarioGridColumn) context.getAbstractScesimGridModelByGridWidget(gridWidget).getColumns().get(index);
                     if (!scenarioGridColumn.isInstanceAssigned()) { // We have not defined the instance, yet
                         setInstanceHeaderMetaData(scenarioGridColumn, instanceAliasName, factIdentifier);
                     }
                 });
-        selectedColumn.getPropertyHeaderMetaData().setColumnGroup(getColumnSubGroup(selectedColumn.getInformationHeaderMetaData().getColumnGroup()));
-        String editableCellPlaceholder = ScenarioSimulationUtils.getPlaceholder(propertyClass);
-        setPropertyMetaData(selectedColumn.getPropertyHeaderMetaData(), propertyTitle, false, selectedColumn, editableCellPlaceholder);
         selectedColumn.setPropertyAssigned(true);
-        context.getModel().updateColumnProperty(columnIndex,
-                                                selectedColumn,
-                                                propertyNameElements,
-                                                propertyClass, context.getStatus().isKeepData());
-        if (ScenarioSimulationSharedUtils.isCollection(propertyClass)) {
+        selectedColumn.getPropertyHeaderMetaData().setColumnGroup(getColumnSubGroup(selectedColumn.getInformationHeaderMetaData().getColumnGroup()));
+        setPropertyMetaData(selectedColumn.getPropertyHeaderMetaData(),
+                            propertyTitle,
+                            false,
+                            selectedColumn,
+                            ScenarioSimulationUtils.getPlaceHolder(selectedColumn.isInstanceAssigned(),
+                                                                   selectedColumn.isPropertyAssigned(),
+                                                                   factMappingValueType,
+                                                                   propertyClass));
+        context.getAbstractScesimGridModelByGridWidget(gridWidget).updateColumnProperty(columnIndex,
+                                                                                        selectedColumn,
+                                                                                        propertyNameElements,
+                                                                                        propertyClass, context.getStatus().isKeepData(),
+                                                                                        factMappingValueType);
+        if (ScenarioSimulationSharedUtils.isCollection(propertyClass) && factMappingValueType.equals(FactMappingValueType.NOT_EXPRESSION)) {
             manageCollectionProperty(context, selectedColumn, className, columnIndex, propertyNameElements);
         } else {
-            selectedColumn.setFactory(context.getScenarioCellTextAreaSingletonDOMElementFactory());
+            selectedColumn.setFactory(context.getAbstractScesimGridModelByGridWidget(gridWidget).getDOMElementFactory(propertyClass,
+                                                                                                                      context.getSettings().getType(),
+                                                                                                                      factMappingValueType));
         }
         if (context.getScenarioSimulationEditorPresenter() != null) {
             context.getScenarioSimulationEditorPresenter().reloadTestTools(false);
@@ -258,11 +283,15 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioSimu
     protected void manageCollectionProperty(ScenarioSimulationContext context, ScenarioGridColumn selectedColumn, String className, int columnIndex, List<String> fullPropertyPathElements) {
         final SortedMap<String, FactModelTree> dataObjectFieldsMap = context.getDataObjectFieldsMap();
         if (className.contains(".")) {
-            className = className.substring(className.lastIndexOf(".") + 1);
+            className = className.substring(className.lastIndexOf('.') + 1);
         }
         final FactModelTree factModelTree = dataObjectFieldsMap.get(className);
-        final FactMapping factMapping = context.getModel().getSimulation().get().getSimulationDescriptor().getFactMappingByIndex(columnIndex);
-        selectedColumn.setFactory(context.getCollectionEditorSingletonDOMElementFactory());
+        final Optional<AbstractScesimModel> selectedScenarioGridModel = context.getAbstractScesimGridModelByGridWidget(gridWidget).getAbstractScesimModel();
+        if (!selectedScenarioGridModel.isPresent()) {
+            throw new IllegalArgumentException("SelectedGrid not found");
+        }
+        final FactMapping factMapping = selectedScenarioGridModel.get().getScesimModelDescriptor().getFactMappingByIndex(columnIndex);
+        selectedColumn.setFactory(context.getCollectionEditorSingletonDOMElementFactory(gridWidget));
         if (factModelTree.isSimple()) {
             factMapping.setGenericTypes(factModelTree.getGenericTypeInfo(ConstantHolder.VALUE));
         } else {
@@ -292,8 +321,11 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioSimu
     }
 
     protected String getPropertyHeaderTitle(ScenarioSimulationContext context, List<String> propertyNameElements, FactIdentifier factIdentifier) {
-        String propertyPathPart = propertyNameElements.size() > 1 ?
-                String.join(".", propertyNameElements.subList(1, propertyNameElements.size())) : "value";
+        /* If propertyNameElements contains only one step, it's managing an Expression or a SimpleClass type */
+        if (propertyNameElements.size() == 1) {
+            return FactMappingValueType.EXPRESSION.equals(factMappingValueType) ? ConstantHolder.EXPRESSION_INSTANCE_PLACEHOLDER : ConstantHolder.VALUE;
+        }
+        String propertyPathPart = String.join(".", propertyNameElements.subList(1, propertyNameElements.size()));
         List<String> propertyNameElementsClone = getPropertyNameElementsWithoutAlias(propertyNameElements, factIdentifier);
         // This is because the propertyName starts with the alias of the fact; i.e. it may be Book.name but also Bookkk.name,
         // while the first element of ExpressionElements is always the class name
@@ -301,7 +333,7 @@ public abstract class AbstractSelectedColumnCommand extends AbstractScenarioSimu
     }
 
     protected Optional<String> getMatchingExpressionAlias(ScenarioSimulationContext context, List<String> propertyNameElements, FactIdentifier factIdentifier) {
-        final List<FactMapping> factMappingsByFactName = context.getStatus().getSimulation().getSimulationDescriptor().getFactMappingsByFactName(factIdentifier.getName());
+        final List<FactMapping> factMappingsByFactName = context.getAbstractScesimModelByGridWidget(gridWidget).getScesimModelDescriptor().getFactMappingsByFactName(factIdentifier.getName());
         return factMappingsByFactName.stream()
                 .filter(factMapping -> {
                     List<String> expressionElements = factMapping.getExpressionElements().stream().map(ExpressionElement::getStep).collect(Collectors.toList());
