@@ -21,6 +21,7 @@ import java.util.List;
 
 import com.google.gwt.event.shared.HandlerRegistration;
 import com.google.gwtmockito.GwtMockitoTestRunner;
+import org.drools.scenariosimulation.api.model.FactMappingValueType;
 import org.drools.workbench.screens.scenariosimulation.client.AbstractScenarioSimulationTest;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.AbstractScenarioSimulationCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.AppendColumnCommand;
@@ -41,6 +42,7 @@ import org.drools.workbench.screens.scenariosimulation.client.commands.actualcom
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.SetHeaderCellValueCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.SetInstanceHeaderCommand;
 import org.drools.workbench.screens.scenariosimulation.client.commands.actualcommands.SetPropertyHeaderCommand;
+import org.drools.workbench.screens.scenariosimulation.client.enums.GridWidget;
 import org.drools.workbench.screens.scenariosimulation.client.events.AppendColumnEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.AppendRowEvent;
 import org.drools.workbench.screens.scenariosimulation.client.events.DeleteColumnEvent;
@@ -210,6 +212,7 @@ public class ScenarioSimulationEventHandlerTest extends AbstractScenarioSimulati
                 this.scenarioCommandManager = scenarioCommandManagerMock;
                 this.scenarioCommandRegistry = scenarioCommandRegistryMock;
                 this.notificationEvent = ScenarioSimulationEventHandlerTest.this.notificationEvent;
+                this.context = scenarioSimulationContextLocal;
             }
         });
     }
@@ -229,80 +232,64 @@ public class ScenarioSimulationEventHandlerTest extends AbstractScenarioSimulati
 
     @Test
     public void onAppendColumnEvent() {
-        AppendColumnEvent event = new AppendColumnEvent(COLUMN_GROUP);
+        AppendColumnEvent event = new AppendColumnEvent(GridWidget.SIMULATION, COLUMN_GROUP);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(AppendColumnCommand.class),
-                                                               eq(true));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(AppendColumnCommand.class), eq(true));
     }
 
     @Test
     public void onAppendRowEvent() {
-        AppendRowEvent event = new AppendRowEvent();
+        AppendRowEvent event = new AppendRowEvent(GridWidget.SIMULATION);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(AppendRowCommand.class),
-                                                               eq(true));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(AppendRowCommand.class), eq(true));
     }
 
     @Test
     public void onDeleteColumnEvent() {
-        DeleteColumnEvent event = new DeleteColumnEvent(COLUMN_INDEX, COLUMN_GROUP, false);
+        DeleteColumnEvent event = new DeleteColumnEvent(GridWidget.SIMULATION, COLUMN_INDEX, COLUMN_GROUP, false);
         when(scenarioGridModelMock.getSelectedColumn()).thenReturn(null);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(DeleteColumnCommand.class),
-                                                               eq(true));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(DeleteColumnCommand.class), eq(true));
     }
 
     @Test
     public void onDeleteRowEvent() {
-        DeleteRowEvent event = new DeleteRowEvent(ROW_INDEX);
+        DeleteRowEvent event = new DeleteRowEvent(GridWidget.SIMULATION, ROW_INDEX);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(DeleteRowCommand.class),
-                                                               eq(true));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(DeleteRowCommand.class), eq(true));
     }
 
     @Test
     public void onDisableTestToolsEvent() {
         DisableTestToolsEvent event = new DisableTestToolsEvent();
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(DisableTestToolsCommand.class),
-                                                               eq(false));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(DisableTestToolsCommand.class), eq(false));
     }
 
     @Test
     public void onDuplicateColumnEvent() {
-        DuplicateInstanceEvent event = new DuplicateInstanceEvent(COLUMN_INDEX);
+        DuplicateInstanceEvent event = new DuplicateInstanceEvent(GridWidget.SIMULATION, COLUMN_INDEX);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(DuplicateInstanceCommand.class),
-                                                               eq(true));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(DuplicateInstanceCommand.class), eq(true));
     }
 
     @Test
     public void onDuplicateRowEvent() {
-        DuplicateRowEvent event = new DuplicateRowEvent(ROW_INDEX);
+        DuplicateRowEvent event = new DuplicateRowEvent(GridWidget.SIMULATION, ROW_INDEX);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(DuplicateRowCommand.class),
-                                                               eq(true));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(DuplicateRowCommand.class), eq(true));
     }
 
     @Test
     public void onEnableTestToolsEvent() {
         EnableTestToolsEvent event = new EnableTestToolsEvent();
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(EnableTestToolsCommand.class),
-                                                               eq(false));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(EnableTestToolsCommand.class), eq(false));
     }
 
     @Test
     public void onImportEvent() {
-        ImportEvent event = new ImportEvent();
+        ImportEvent event = new ImportEvent(GridWidget.SIMULATION);
         scenarioSimulationEventHandler.onEvent(event);
         verify(fileUploadPopupPresenterMock, times(1))
                 .show(anyListOf(String.class),
@@ -313,38 +300,30 @@ public class ScenarioSimulationEventHandlerTest extends AbstractScenarioSimulati
 
     @Test
     public void onInsertColumnEvent() {
-        InsertColumnEvent event = new InsertColumnEvent(COLUMN_INDEX, true, false);
+        InsertColumnEvent event = new InsertColumnEvent(GridWidget.SIMULATION, COLUMN_INDEX, true, false);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(InsertColumnCommand.class),
-                                                               eq(true));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(InsertColumnCommand.class), eq(true));
     }
 
     @Test
     public void onInsertRowEvent() {
-        InsertRowEvent event = new InsertRowEvent(ROW_INDEX);
+        InsertRowEvent event = new InsertRowEvent(GridWidget.SIMULATION, ROW_INDEX);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(InsertRowCommand.class),
-                                                               eq(true));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(InsertRowCommand.class), eq(true));
     }
 
     @Test
     public void onPrependColumnEvent() {
-        PrependColumnEvent event = new PrependColumnEvent(COLUMN_GROUP);
+        PrependColumnEvent event = new PrependColumnEvent(GridWidget.SIMULATION, COLUMN_GROUP);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(PrependColumnCommand.class),
-                                                               eq(true));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(PrependColumnCommand.class), eq(true));
     }
 
     @Test
     public void onPrependRowEvent() {
-        PrependRowEvent event = new PrependRowEvent();
+        PrependRowEvent event = new PrependRowEvent(GridWidget.SIMULATION);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(PrependRowCommand.class),
-                                                               eq(true));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(PrependRowCommand.class), eq(true));
     }
 
     @Test
@@ -358,69 +337,62 @@ public class ScenarioSimulationEventHandlerTest extends AbstractScenarioSimulati
     public void onReloadTestToolsEvent() {
         ReloadTestToolsEvent event = new ReloadTestToolsEvent(true);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(ReloadTestToolsCommand.class),
-                                                               eq(false));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(ReloadTestToolsCommand.class), eq(false));
     }
 
     @Test
     public void onRunSingleScenarioPanelEvent() {
         RunSingleScenarioEvent event = new RunSingleScenarioEvent(ROW_INDEX);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(RunSingleScenarioCommand.class),
-                                                               eq(false));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(RunSingleScenarioCommand.class), eq(false));
     }
 
     @Test
-    public void onScenarioGridReloadEvent() {
-        ScenarioGridReloadEvent event = new ScenarioGridReloadEvent();
-        scenarioSimulationEventHandler.handle(event);
+    public void onScenarioGridReloadEventSIMULATION() {
+        ScenarioGridReloadEvent event = new ScenarioGridReloadEvent(GridWidget.SIMULATION);
+        scenarioSimulationEventHandler.onEvent(event);
         verify(scenarioGridPanelMock, times(1)).onResize();
     }
 
     @Test
-    public void onSetGridCellValueEvent() {
-        SetGridCellValueEvent event = new SetGridCellValueEvent(ROW_INDEX, COLUMN_INDEX, MULTIPART_VALUE);
+    public void onScenarioGridReloadEventBACKGROUND() {
+        ScenarioGridReloadEvent event = new ScenarioGridReloadEvent(GridWidget.BACKGROUND);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(SetGridCellValueCommand.class),
-                                                               eq(false));
+        verify(backgroundGridPanelMock, times(1)).onResize();
+    }
+
+    @Test
+    public void onSetGridCellValueEvent() {
+        SetGridCellValueEvent event = new SetGridCellValueEvent(GridWidget.SIMULATION, ROW_INDEX, COLUMN_INDEX, MULTIPART_VALUE);
+        scenarioSimulationEventHandler.onEvent(event);
+        verify(scenarioSimulationEventHandler).commonExecution(isA(SetGridCellValueCommand.class), eq(false));
     }
 
     @Test
     public void onSetHeaderCellValueEventInstanceHeader() {
-        SetHeaderCellValueEvent event = new SetHeaderCellValueEvent(ROW_INDEX, COLUMN_INDEX, MULTIPART_VALUE, true, false);
+        SetHeaderCellValueEvent event = new SetHeaderCellValueEvent(GridWidget.SIMULATION, ROW_INDEX, COLUMN_INDEX, MULTIPART_VALUE, true, false);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(SetHeaderCellValueCommand.class),
-                                                               eq(false));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(SetHeaderCellValueCommand.class), eq(false));
     }
 
     @Test
     public void onSetHeaderCellValueEventPropertyHeader() {
-        SetHeaderCellValueEvent event = new SetHeaderCellValueEvent(ROW_INDEX, COLUMN_INDEX, MULTIPART_VALUE, false, true);
+        SetHeaderCellValueEvent event = new SetHeaderCellValueEvent(GridWidget.SIMULATION, ROW_INDEX, COLUMN_INDEX, MULTIPART_VALUE, false, true);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(SetHeaderCellValueCommand.class),
-                                                               eq(false));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(SetHeaderCellValueCommand.class), eq(false));
     }
 
     @Test
     public void onSetInstanceHeaderEvent() {
-        SetInstanceHeaderEvent event = new SetInstanceHeaderEvent(FULL_PACKAGE, FULL_CLASS_NAME);
+        SetInstanceHeaderEvent event = new SetInstanceHeaderEvent(GridWidget.SIMULATION, FULL_PACKAGE, FULL_CLASS_NAME);
         when(scenarioGridModelMock.getSelectedColumn()).thenReturn(null);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler, never()).commonExecution(eq(scenarioSimulationContextLocal),
-                                                                        isA(SetInstanceHeaderCommand.class),
-                                                                        anyBoolean());
+        verify(scenarioSimulationEventHandler, never()).commonExecution(isA(SetInstanceHeaderCommand.class), anyBoolean());
         //
         doReturn(gridColumnMock).when(scenarioGridModelMock).getSelectedColumn();
         when(scenarioGridModelMock.isSameSelectedColumnType(anyString())).thenReturn(true);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler, never()).commonExecution(eq(scenarioSimulationContextLocal),
-                                                                        isA(SetInstanceHeaderCommand.class),
-                                                                        anyBoolean());
+        verify(scenarioSimulationEventHandler, never()).commonExecution(isA(SetInstanceHeaderCommand.class), anyBoolean());
         //
         when(scenarioGridModelMock.isSameInstanceType(anyString())).thenReturn(false);
         when(gridColumnMock.isInstanceAssigned()).thenReturn(true);
@@ -433,51 +405,39 @@ public class ScenarioSimulationEventHandlerTest extends AbstractScenarioSimulati
                       eq(ScenarioSimulationEditorConstants.INSTANCE.changeTypeTextDanger()),
                       eq(ScenarioSimulationEditorConstants.INSTANCE.changeType()),
                       isA(org.uberfire.mvp.Command.class));
-        verify(scenarioSimulationEventHandler, never()).commonExecution(eq(scenarioSimulationContextLocal),
-                                                                        isA(SetInstanceHeaderCommand.class),
-                                                                        anyBoolean());
+        verify(scenarioSimulationEventHandler, never()).commonExecution(isA(SetInstanceHeaderCommand.class), anyBoolean());
 
         when(scenarioGridModelMock.isSameSelectedColumnType(anyString())).thenReturn(false);
         when(gridColumnMock.isInstanceAssigned()).thenReturn(false);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(SetInstanceHeaderCommand.class),
-                                                               eq(true));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(SetInstanceHeaderCommand.class), eq(true));
     }
 
     @Test
     public void onSetPropertyHeaderEvent() {
-        SetPropertyHeaderEvent event = new SetPropertyHeaderEvent(FULL_PACKAGE, MULTIPART_VALUE_ELEMENTS, VALUE_CLASS_NAME);
+        SetPropertyHeaderEvent event = new SetPropertyHeaderEvent(GridWidget.SIMULATION, FULL_PACKAGE, MULTIPART_VALUE_ELEMENTS, VALUE_CLASS_NAME, FactMappingValueType.NOT_EXPRESSION);
         when(scenarioGridModelMock.getSelectedColumn()).thenReturn(null);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler, never()).commonExecution(eq(scenarioSimulationContextLocal),
-                                                                        isA(SetPropertyHeaderCommand.class),
-                                                                        anyBoolean());
+        verify(scenarioSimulationEventHandler, never()).commonExecution(isA(SetPropertyHeaderCommand.class), anyBoolean());
         //
         doReturn(gridColumnMock).when(scenarioGridModelMock).getSelectedColumn();
         when(scenarioGridModelMock.isAlreadyAssignedProperty(MULTIPART_VALUE_ELEMENTS)).thenReturn(true);
         scenarioSimulationEventHandler.onEvent(event);
         verify(scenarioSimulationEventHandler, times(1)).onEvent(isA(ScenarioNotificationEvent.class));
-        verify(scenarioSimulationEventHandler, never()).commonExecution(eq(scenarioSimulationContextLocal),
-                                                                        isA(SetPropertyHeaderCommand.class),
-                                                                        anyBoolean());
+        verify(scenarioSimulationEventHandler, never()).commonExecution(isA(SetPropertyHeaderCommand.class), anyBoolean());
         //
         reset(scenarioSimulationEventHandler);
         when(scenarioGridModelMock.isAlreadyAssignedProperty(MULTIPART_VALUE_ELEMENTS)).thenReturn(false);
         when(scenarioGridModelMock.isSelectedColumnEmpty()).thenReturn(true);
         scenarioSimulationEventHandler.onEvent(event);
         verify(scenarioSimulationEventHandler, never()).onEvent(isA(ScenarioNotificationEvent.class));
-        verify(scenarioSimulationEventHandler).commonExecution(eq(scenarioSimulationContextLocal),
-                                                               isA(SetPropertyHeaderCommand.class),
-                                                               eq(true));
+        verify(scenarioSimulationEventHandler).commonExecution(isA(SetPropertyHeaderCommand.class), eq(true));
         //
         reset(scenarioSimulationEventHandler);
         when(scenarioGridModelMock.isSelectedColumnEmpty()).thenReturn(false);
         when(scenarioGridModelMock.isSameSelectedColumnProperty(anyListOf(String.class))).thenReturn(true);
         scenarioSimulationEventHandler.onEvent(event);
-        verify(scenarioSimulationEventHandler, never()).commonExecution(eq(scenarioSimulationContextLocal),
-                                                                        isA(SetPropertyHeaderCommand.class),
-                                                                        anyBoolean());
+        verify(scenarioSimulationEventHandler, never()).commonExecution(isA(SetPropertyHeaderCommand.class), anyBoolean());
         //
         when(scenarioGridModelMock.isSameSelectedColumnProperty(anyListOf(String.class))).thenReturn(false);
         when(scenarioGridModelMock.isSameSelectedColumnType(anyString())).thenReturn(true);
@@ -493,9 +453,7 @@ public class ScenarioSimulationEventHandlerTest extends AbstractScenarioSimulati
                       eq(ScenarioSimulationEditorConstants.INSTANCE.deleteValues()),
                       isA(org.uberfire.mvp.Command.class),
                       isA(org.uberfire.mvp.Command.class));
-        verify(scenarioSimulationEventHandler, never()).commonExecution(eq(scenarioSimulationContextLocal),
-                                                                        isA(SetPropertyHeaderCommand.class),
-                                                                        anyBoolean());
+        verify(scenarioSimulationEventHandler, never()).commonExecution(isA(SetPropertyHeaderCommand.class), anyBoolean());
         //
         when(scenarioGridModelMock.isSameSelectedColumnType(anyString())).thenReturn(false);
         scenarioSimulationEventHandler.onEvent(event);
@@ -507,9 +465,7 @@ public class ScenarioSimulationEventHandlerTest extends AbstractScenarioSimulati
                       eq(ScenarioSimulationEditorConstants.INSTANCE.deleteScenarioTextDanger()),
                       eq(ScenarioSimulationEditorConstants.INSTANCE.deleteValues()),
                       isA(org.uberfire.mvp.Command.class));
-        verify(scenarioSimulationEventHandler, never()).commonExecution(eq(scenarioSimulationContextLocal),
-                                                                        isA(SetPropertyHeaderCommand.class),
-                                                                        anyBoolean());
+        verify(scenarioSimulationEventHandler, never()).commonExecution(isA(SetPropertyHeaderCommand.class), anyBoolean());
     }
 
     @Test
@@ -530,14 +486,14 @@ public class ScenarioSimulationEventHandlerTest extends AbstractScenarioSimulati
     @Test
     public void commonExecution() {
         when(scenarioCommandManagerMock.execute(eq(scenarioSimulationContextLocal), eq(appendRowCommandMock))).thenReturn(CommandResultBuilder.SUCCESS);
-        scenarioSimulationEventHandler.commonExecution(scenarioSimulationContextLocal, appendRowCommandMock, true);
+        scenarioSimulationEventHandler.commonExecution(appendRowCommandMock, true);
         assertEquals(simulationMock, scenarioSimulationContextLocal.getStatus().getSimulation());
         verify(scenarioCommandRegistryMock, times(1)).register(eq(scenarioSimulationContextLocal), eq(appendRowCommandMock));
         //
         reset(scenarioCommandRegistryMock);
         CommandResult<ScenarioSimulationViolation> status = new CommandResultImpl<>(CommandResult.Type.ERROR, Collections.singletonList(new ScenarioSimulationViolation("FAKE ERROR")));
         when(scenarioCommandManagerMock.execute(eq(scenarioSimulationContextLocal), eq(appendRowCommandMock))).thenReturn(status);
-        scenarioSimulationEventHandler.commonExecution(scenarioSimulationContextLocal, appendRowCommandMock, true);
+        scenarioSimulationEventHandler.commonExecution(appendRowCommandMock, true);
         assertEquals(simulationMock, scenarioSimulationContextLocal.getStatus().getSimulation());
         verify(scenarioCommandRegistryMock, never()).register(eq(appendRowCommandMock));
     }
